use strict;
use warnings;
package Acme::CPANTesters::Experiment;
# ABSTRACT: This is surely not the module you are looking for. I'm testing various things related to CPANTesters

=head1 NAME

Acme::CPANTesters::Experiment - Experimenting with CPANTesters

=head1 DESCRIPTION

This is not the module you are looking for.
I'm testing various things related to CPANTesters

=cut

1;
